@@ -1,4 +1,5 @@
 use crate::quote;
+use std::borrow::{Cow, ToOwned};
 
 pub trait SqlArg {
     fn sql_arg(&self) -> String;
@@ -16,6 +17,12 @@ impl SqlArg for &str {
     }
 }
 
+impl SqlArg for Cow<'_, str> {
+    fn sql_arg(&self) -> String {
+        quote(self[..].to_owned())
+    }
+}
+
 impl SqlArg for String {
     fn sql_arg(&self) -> String {
         quote(self)
@@ -166,6 +173,30 @@ impl SqlArg for &usize {
     }
 }
 
+impl SqlArg for f32 {
+    fn sql_arg(&self) -> String {
+        self.to_string()
+    }
+}
+
+impl SqlArg for &f32 {
+    fn sql_arg(&self) -> String {
+        self.to_string()
+    }
+}
+
+impl SqlArg for f64 {
+    fn sql_arg(&self) -> String {
+        self.to_string()
+    }
+}
+
+impl SqlArg for &f64 {
+    fn sql_arg(&self) -> String {
+        self.to_string()
+    }
+}
+
 impl SqlArg for bool {
     fn sql_arg(&self) -> String {
         String::from(if *self { "TRUE" } else { "FALSE" })
